"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function getTypedArray(dataview, metadata) {
    switch (metadata.dtype) {
        case 'int32':
            return new Int32Array(dataview.buffer);
            break;
        default:
            throw 'Unknown dtype ' + metadata.dtype;
            break;
    }
}
var Scalar;
(function (Scalar) {
    function isScalar(x) {
        return x === null || typeof x === "boolean" || typeof x === "number" || typeof x === "string";
    }
    Scalar.isScalar = isScalar;
})(Scalar || (Scalar = {}));
// Buffered argument
class Arg {
}
exports.Arg = Arg;
class ScalarArg extends Arg {
    constructor(value) {
        super();
        this.value = value;
        this.length = Infinity;
    }
    getItem(idx) {
        return this.value;
    }
}
class BufferArg extends Arg {
    constructor(bufferMetadata, buffer) {
        super();
        this.value = getTypedArray(buffer, bufferMetadata);
        this.length = this.value.length;
    }
    getItem(idx) {
        return this.value[idx];
    }
}
function getArg(metadata, buffers) {
    if (Scalar.isScalar(metadata)) {
        return new ScalarArg(metadata);
    }
    if (metadata['idx'] !== undefined) {
        return new BufferArg(metadata, buffers[metadata['idx']]);
    }
    throw 'Could not process argument ' + metadata;
}
exports.getArg = getArg;
//# sourceMappingURL=utils.js.map